@@ -23,19 +23,19 @@ generate <- function(model, n, maxDraw = 50, misfitBounds = NULL, misfitType = "
 			# Intentionally leave it blank
 		} else if (is(model, "lavaan")) {
 			temp <- model@ParTable
-			temp$ustart <- model@Fit@est
+			temp$ustart <- temp$est # model@Fit@est 
 			model <- list(model = temp)
 		} else {
 			stop("Please specify an appropriate object for the 'model' argument: simsem model template, lavaan script, lavaan parameter table, OpenMx object, or list of options for the 'simulateData' function.")
 		}
 		model$sample.nobs <- n
 		if(!is.null(indDist)) {
-			model$indDist <- indDist@skewness
+			model$skewness <- indDist@skewness
 			model$kurtosis <- indDist@kurtosis
 		}
 		model$empirical <- empirical
 		model <- c(model, list(...))
-		data <- do.call("simulateData", model) 
+		data <- do.call(lavaan::simulateData, model) 
 	}
 	return(data)
 }
